# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorarch: %global perl_vendorarch %(eval "`perl -V:installvendorarch`"; echo $installvendorarch)}

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

# We can't have Coro with perl < 5.8.8
%global coro_available %(perl -e 'print $] >= 5.008008 ? 1 : 0;' 2>/dev/null || echo 0)

Name:		perl-DBI
Version:	1.618
Release:	1.%{__distinit}%{__distvers}
Summary:	A database access API for perl
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://dbi.perl.org/
Source0:	http://search.cpan.org/CPAN/authors/id/T/TI/TIMB/DBI-%{version}.tar.gz
Source1:	perl-module-version-filter
Patch0:		DBI-1.616-shellbang.patch
Patch1:		DBI-1.617-utf8.patch
Patch2:		DBI-1.616-old-Test::More.patch
Patch3:		DBI-1.615-old-perl.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	perl >= 3:5.8.1
%if %{coro_available}
BuildRequires:	perl(Coro)
BuildRequires:	perl(Coro::Handle)
BuildRequires:	perl(Coro::Select)
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(MLDBM)
BuildRequires:	perl(RPC::PlClient)
# SQL::Statement -> DBI
%if %(perl -MScalar::Util -e 'print (($Scalar::Util::VERSION < 1.14) ? 0 : 1);' 2>/dev/null || echo 0) && 0%{!?perl_bootstrap:1}
BuildRequires:	perl(SQL::Statement)
%endif
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Pod::Coverage)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Avoid unwanted provides and dependencies (rpm 4.9 onwards)
%global __requires_exclude ^perl\\((RPC::.*|DBI::Util::_accessor)\\)
%global __provides_exclude ^DBI\\.so

%description 
DBI is a database access Application Programming Interface (API) for
the Perl Language. The DBI API Specification defines a set of
functions, variables and conventions that provide a consistent
database interface independent of the actual database being used.

%prep
%setup -q -n DBI-%{version} 

# Fix shellbangs
%patch0 -p1

# Recode as UTF-8
%patch1 -p1

# Fix tests for Test::More prior to 0.88
%if %{old_test_more}
%patch2 -p1
%endif

# File::Path 1.06 and earlier don't do rmtree properly and cause noise in the
# test suite, so if that's what we've got, hack the test suite to use a local
# copy of File::Path 1.08 instead.
#
# Note that FC-3, FC-4, EL-4 have patched versions of File::Path 1.06 that work
# OK but we'll hack the test suite anyway since it's hard to tell if the
# module is patched.
%if %(perl -MFile::Path -e 'print $File::Path::VERSION <= 1.06 ? 1 : 0;')
%patch3 -p1
%endif

# Fix permissions
chmod -c 755 dbixs_rev.pl

# Avoid unwanted dependencies (prior to rpm 4.9)
%global reqfilt /bin/sh -c "%{__perl_requires} | grep -Ev '^perl\\((RPC::.*|DBI::Util::_accessor)\\)'"
%define __perl_requires %{reqfilt}

# Auto provides aren't clever enough for what DBI does
%global build_dir %{_builddir}/%{buildsubdir}
%global filter_chain | perl -n -s %{SOURCE1} -installdir=%{buildroot}%{perl_vendorarch}
%if 0%{?__perllib_provides:1}
%global perllib_filt /bin/sh -c "%{__perllib_provides} %{filter_chain}"
%define __perllib_provides %{perllib_filt}
%else
%global perl_filt /bin/sh -c "%{__perl_provides} %{filter_chain}"
%define __perl_provides %{perl_filt}
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
find %{buildroot} -depth -type d -exec rmdir {} ';' 2>/dev/null
chmod -R u+w %{buildroot}

# Remove Win32-specific files and manpages to avoid unwanted dependencies
rm -rf %{buildroot}%{perl_vendorarch}/{Win32,DBI/W32ODBC.pm}
rm -f %{buildroot}%{_mandir}/man3/{DBI::W32,Win32::DBI}ODBC.3pm

# Don't ship DBD::Gofer::Transport::corostream if Coro not available
%if !%{coro_available}
rm %{buildroot}%{perl_vendorarch}/DBD/Gofer/Transport/corostream.pm
%endif

%check
# Use our hacked File::Path if necessary
[ -f inc/File/Path108.pm ] && export PERL5LIB=$(pwd)/inc

make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc README ex/
%{_bindir}/dbilogstrip
%{_bindir}/dbiprof
%{_bindir}/dbiproxy
%{perl_vendorarch}/DBI.pm
%{perl_vendorarch}/dbixs_rev.pl
%{perl_vendorarch}/Bundle/
%{perl_vendorarch}/DBD/
%{perl_vendorarch}/DBI/
%{perl_vendorarch}/auto/DBI/
%{_mandir}/man1/dbilogstrip.1*
%{_mandir}/man1/dbiprof.1*
%{_mandir}/man1/dbiproxy.1*
%{_mandir}/man3/Bundle::DBI.3pm*
%{_mandir}/man3/DBD::*.3pm*
%{_mandir}/man3/DBI.3pm*
%{_mandir}/man3/DBI::*3pm*

%changelog
* Sun Feb 26 2012 Paul Howarth <paul@city-fan.org> - 1.618-1
- update to 1.618
  - fixed compiler warnings in Driver_xst.h
  - fixed compiler warning in DBI.xs
  - fixed Gofer tests failing on Windows (CPAN RT#74975)
  - fixed my_ctx compile errors on Windows
  - significantly optimized method dispatch via cache
  - significantly optimized DBI internals for threads
  - xsub to xsub calling optimization now enabled for threaded perls
  - corrected typo in example in docs
  - added note that calling clone() without an arg may warn in future
  - minor changes to the install_method() docs in DBI::DBD
  - updated dbipport.h from Devel::PPPort 3.20

* Fri Feb 10 2012 Paul Howarth <paul@city-fan.org> - 1.617-2
- don't BR: perl(SQL::Statement) if we're bootstrapping

* Mon Jan 30 2012 Paul Howarth <paul@city-fan.org> - 1.617-1
- update to 1.617
  - NOTE: The officially supported minimum perl version will change from
    perl 5.8.1 (2003) to perl 5.8.3 (2004) in a future release
  - fixed ParamTypes example in the pod
  - fixed the definition of ArrayTupleStatus and remove confusion over rows
    affected in list context of execute_array
  - fixed sql_type_cast example and typo in errors
  - fixed Gofer error handling for keeperr methods like ping
  - fixed $dbh->clone({}) (CPAN RT#73250)
  - fixed is_nested_call logic error (CPAN RT#73118)
  - enhanced performance for threaded perls
  - enhanced and standardized driver trace level mechanism
  - removed old code that was an ineffective attempt to detect people doing
    DBI->{Attrib}
  - clear ParamValues on bind_param param count error (CPAN RT#66127)
  - changed DBI::ProxyServer to require DBI at compile-time (CPAN RT#62672)
  - added pod for default_user to DBI::DBD
  - added CON, ENC and DBD trace flags and extended 09trace.t
  - added TXN trace flags and applied CON and TXN to relevant methods
  - added some more fetchall_arrayref(..., $maxrows) tests
  - clarified docs for fetchall_arrayref called on an inactive handle
  - clarified docs for clone method
  - added note to DBI::Profile about async queries
  - reserved spatialite_ as a driver prefix for DBD::Spatialite
  - reserved mo_ as a driver prefix for DBD::MO
  - updated link to the SQL Reunion 95 docs (CPAN RT#69577)
  - changed links for DBI recipes (CPAN RT#73286)
- BR: perl(RPC::PlClient) for extra test cover and to ensure that we can grok all of
  the module versions

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 1.616-4
- rebuild for perl 5.14.1 in Rawhide
- make requires/provides filters work properly across all distributions
- nobody else likes macros for commands
- fix dist tag for CentOS 6 and Scientific Linux

* Mon Jan 24 2011 Paul Howarth <paul@city-fan.org> - 1.616-2
- BR: perl(Coro), perl(Coro::Handle), perl(Coro::Select) if available (5.8.8+)
- don't filter Coro dependencies
- don't ship DBD::Gofer::Transport::corostream if Coro not available

* Tue Jan  4 2011 Paul Howarth <paul@city-fan.org> - 1.616-1
- update to 1.616
  - fixed spurious dbi_profile lines written to the log when profiling is
    enabled and a trace flag, like SQL, is used
  - fixed to recognize SQL::Statement errors even if instantiated with
    RaiseError=0
  - fixed CPAN RT#61513 by catching attribute assignment to tied table access
    interface
  - fixed some misbehaviour of DBD::File when running within the Gofer server
  - fixed compiler warnings (CPAN RT#62640)
  - optimized connect() to remove redundant FETCH of \%%attrib values
  - improved initialization phases in DBI::DBD::SqlEngine
  - added DBD::Gofer::Transport::corostream, an experimental proof-of-concept
    transport that enables asynchronous database calls with few code changes
  - added additional notes on DBDs that avoid creating a statement in the do()
    method and the effects on error handlers
  - added new attribute "sql_dialect" to DBI::DBD::SqlEngine to allow users
    control over the used SQL dialect (ANSI, CSV or AnyData), defaults to CSV
  - added documentation for DBI::DBD::SqlEngine attributes
  - documented dbd_st_execute return
  - fixed typo in InactiveDestroy
- update patches for shellbangs and old Test::More versions
- filter out dependencies on unavailable perl-Coro modules for now

* Fri Oct  1 2010 Paul Howarth <paul@city-fan.org> - 1.615-2
- rebuild for gcc bug (#634757)

* Thu Sep 23 2010 Paul Howarth <paul@city-fan.org> - 1.615-1
- update to 1.615
  - fixed t/51dbm_file for file/directory names with whitespace (CPAN RT#61445)
  - fixed compiler warnings from ignored hv_store result
  - fixed portability to VMS
- update patch for old Test::More versions
- use local version of File::Path 1.08 if system version is older than that,
  so as to reduce noise in test output

* Fri Sep 17 2010 Paul Howarth <paul@city-fan.org> - 1.614-1
- update to 1.614 (see Changes for details)
- Roadmap and TASKS documentation dropped by upstream
- update UTF-8 and old Test::More patches

* Tue Aug 10 2010 Paul Howarth <paul@city-fan.org> - 1.613-2
- add BR: perl(MLDBM) and perl(SQL::Statement) for improved test coverage
- update patch for old Test::More versions

* Mon Jul 26 2010 Paul Howarth <paul@city-fan.org> - 1.613-1
- update to 1.613
  - fixed Win32 prerequisite module from PathTools to File::Spec
  - changed attribute headings and fixed references in DBI pod
  - corrected typos in DBI::FAQ and DBI::ProxyServer

* Mon Jul 19 2010 Paul Howarth <paul@city-fan.org> - 1.612-1
- update to 1.612 (see Changes for details)
- update patch for old Test::More versions and apply it if we have Test::More
  older than 0.88 as the test suite now uses done_testing()

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.611-3
- rebuild for perl 5.12.1 in Rawhide

* Tue Jun  1 2010 Paul Howarth <paul@city-fan.org> - 1.611-2
- fix dist tag for RHEL-6 Beta

* Fri Apr 30 2010 Paul Howarth <paul@city-fan.org> - 1.611-1
- update to 1.611
  - minimum perl version is now 5.8.1
  - fixed selectcol_arrayref MaxRows attribute to count rows, not values
  - fixed DBI->trace(0, *STDERR)
  - fixes in DBD::DBM for use under threads
  - "rollback() due to DESTROY" warning not issued if ReadOnly set for that dbh
  - added f_lock and f_encoding support to DBD::File
  - added ChildCallbacks => { ... } to specify Callbacks for child handles
  - added DBI::sql_type_cast($value,$type,$flags) to cast string to an SQL type
  - many documentation updates
  - updated dbipport.h to Devel::PPPort 3.19
- add patch to fix test suite for Test::More < 0.84

* Mon Apr 12 2010 Paul Howarth <paul@city-fan.org> - 1.609-5
- import from Fedora
- fix versioned provides for all submodules - properly

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.609-4
- rebuild against perl 5.10.1

* Thu Sep 24 2009 Stepan Kasal <skasal@redhat.com> - 1.609-3
- provide versioned perl(DBI)

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.609-2
- rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jun 10 2009 Stepan Kasal <skasal@redhat.com> - 1.609-1
- new upstream version
- drop unneeded build patch
- move the iconv to convert the source

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.607-2
- rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jul 28 2008 Marcela Maslanova <mmaslano@redhat.com> - 1.607-1
- update

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.601-4
- rebuild for perl 5.10 (again)

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.601-3
- Autorebuild for GCC 4.3

* Tue Jan 15 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.601-2
- rebuild for new perl

* Fri Oct 26 2007 Robin Norwood <rnorwood@redhat.com> - 1.601-1
- update to latest CPAN version: 1.601
- fix some issues from package review:
  - patch to change #! line in script
  - make script executable
  - fix requires and buildrequires

* Mon Aug 27 2007 Robin Norwood <rnorwood@redhat.com> - 1.58-2
- rebuild

* Mon Aug 13 2007 Robin Norwood <rnorwood@redhat.com> - 1.58-1
- update to latest CPAN version: 1.58

* Thu Jun 07 2007 Robin Norwood <rnorwood@redhat.com> - 1.56-1
- update to latest CPAN version: 1.56
- move the filter requires step into %%prep
- remove very old patch (for perl 5.8.1)
- fix a couple of rpmlint issues (non-UTF8 manpage and script with
  incorrect shebang line

* Sat Dec 02 2006 Robin Norwood <rnorwood@redhat.com> - 1.53-1
- upgrade to latest CPAN version: 1.53

* Thu Aug 24 2006 Robin Norwood <rnorwood@redhat.com> - 1.52-1
- upgrade to 1.52 for bug #202310
	
* Mon Jul 17 2006 Jason Vas Dias <jvdias@redhat.com> - 1.51-1
- upgrade to 1.51

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.50-3
- rebuild

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.50-2.2
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.50-2.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Feb 03 2006 Jason Vas Dias <jvdias@redhat.com> - 1.50-2
- rebuild for new perl-5.8.8 / gcc / glibc

* Mon Dec 19 2005 Jason Vas Dias<jvdias@redhat.com> - 1.50-1
- upgrade to 1.50

* Fri Dec 16 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt for new gcc

* Fri Dec 16 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt for new gcj

* Wed Apr 13 2005 Jose Pedro Oliveira <jpo@di.uminho.pt> - 1.48-4
- (#154762)
- license information: GPL or Artistic
- removed the Time::HiRes building requirement (see Changes)
- removed the empty .bs file
- corrected file permissions

* Mon Apr 04 2005 Warren Togami <wtogami@redhat.com> - 1.48-3
- filter perl(Apache) (#153673)

* Fri Apr 01 2005 Robert Scheck <redhat@linuxnetz.de> - 1.48-2
- spec file cleanup (#153164)

* Thu Mar 31 2005 Warren Togami <wtogami@redhat.com> - 1.48-1
- 1.48

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Chip Turner <cturner@redhat.com> - 1.40-1
- update to 1.40

* Fri Dec 19 2003 Chip Turner <cturner@redhat.com> - 1.39-1
- update to 1.39

* Mon Jul  7 2003 Chip Turner <cturner@redhat.com> - 1.37-1
- upgrade to 1.37

* Wed Apr  2 2003 Chip Turner <cturner@redhat.com> - 1.32-6
- add buildrequires on perl-Time-HiRes

* Tue Feb 18 2003 Chip Turner <cturner@redhat.com>
- update dependency filter to remove dependency on perl(Apache) that
  crept in (#82927)

* Mon Jan 27 2003 Chip Turner <cturner@redhat.com>
- version bump and rebuild

* Sat Dec 14 2002 Chip Turner <cturner@redhat.com>
- don't use rpm internal dep generator

* Wed Nov 20 2002 Chip Turner <cturner@redhat.com>
- rebuild

* Wed Aug  7 2002 Trond Eivind Glomsrød <teg@redhat.com> - 1.30-1
- 1.30

* Tue Jun 25 2002 Trond Eivind Glomsrød <teg@redhat.com> - 1.28-1
- 1.28
- building it also fixes #66304

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Wed Jun  5 2002 Trond Eivind Glomsrød <teg@redhat.com> - 1.23-2
- tweak dependency finder - filter out a dependency found within the 
  doc section of a module

* Tue Jun  4 2002 Trond Eivind Glomsrød <teg@redhat.com> - 1.23-1
- 1.23
- some changes to integrate with new Perl
- update URL

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Tue May  7 2002 Trond Eivind Glomsrød <teg@redhat.com> - 1.21-2
- rebuild

* Fri Feb 22 2002 Trond Eivind Glomsrød <teg@redhat.com> - 1.21-1
- 1.21

* Fri Feb  8 2002 Chip Turner <cturner@redhat.com>
- filter out "soft" dependencies: perl(RPC::PlClient) and perl(Win32::ODBC)

* Thu Feb  7 2002 Trond Eivind Glomsrød <teg@redhat.com> - 1.201-2
- rebuild

* Tue Jan 22 2002 Trond Eivind Glomsrød <teg@redhat.com> - 1.201-1
- 1.201

* Wed Jan 09 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Tue Jan  8 2002 Trond Eivind Glomsrød <teg@redhat.com> - 1.20-1
- 1.20
- proper URL

* Sat Jun 23 2001 Trond Eivind Glomsrød <teg@redhat.com>
- 1.18

* Wed May 30 2001 Trond Eivind Glomsrød <teg@redhat.com>
- 1.16
- change group to Applications/Databases from Applications/CPAN

* Tue May  1 2001 Trond Eivind Glomsrød <teg@redhat.com>
- 1.15

* Tue Feb 27 2001 Trond Eivind Glomsrød <teg@redhat.com>
- cleanups

* Thu Nov 30 2000 Trond Eivind Glomsrød <teg@redhat.com>
- build for main distribution
- use %%{_tmppath}
- change name of specfile
- don't use a find script to generate file lists
- general cleanup
- add descriptive summary and description

* Mon Aug 14 2000 Tim Powers <timp@redhat.com>
- spec file was autogenerated.
